# Copyright (C) 1999, 2000 Jay Beale
# Licensed under the GNU General Public License

package Bastille::MiscellaneousDaemons;

use Bastille::API;

@ENV="";
$ENV{PATH}="";
$ENV{CDPATH}=".";
$ENV{BASH_ENV}="";



#######################################################################
##                          Miscellaneous Daemons                    ##
#######################################################################

# Deactivate ?standard? services chosen at install, at admin's option.
# Explain why they might want to turn this stuff off.  Remember, most
# newbies will take the, "I don't want to break anything -- turn it all on!"
# approach.  Let's deactivate apmd, portmap, atd, pcmcia, nfs, netfs, smb, 
# dhcpd, amd, gpm, innd, linuxconf, if possible.

&DeactivateAPMD;
&DeactivateRemoteFS;
&DeactivateATD;
&DeactivatePCMCIA;
&DeactivateDHCP;
&DeactivateGPM;
&DeactivateINND;

#
# Disable non-standard services, which may have been badly chosen at install:
#
# Possibly disable arpwatch, autofs, bootparamd, gated, mars-nwe, mcserv,
# postgresql, routed, rstatd, rusersd, rwalld, rwhod, snmpd, squid, xntpd, 
# ypbind, yppasswdd, ypserv

#
#### WHICH ONES SHOULD WE DISABLE?
#

&DeactivateRoutingDaemons;
&DeactivateNIS;
&DeactivateSNMPD;


sub DeactivateAPMD {

    if ($GLOBAL_CONFIG{"MiscellaneousDaemons"}{"apmd"} eq "Y") {
	&ActionLog("# sub DeactivateAPMD\n");

	&B_chkconfig_off ("apmd");
   }
}

sub DeactivateRemoteFS {

    if ($GLOBAL_CONFIG{"MiscellaneousDaemons"}{"remotefs"} eq "Y") {
	&ActionLog("# sub DeactivateRemoteFS\n");

# For now, we break NFS/SAMBA.  Does someone want to make a "secure?" NFS
# configuration?  Should we allow samba? Can we use samba without the 
# automounter? Are they safe when we don't know if the admin has a firewall?

      &B_chkconfig_off ("portmap");
      &B_chkconfig_off ("nfs");
      &B_chkconfig_off ("smb");
      &B_chkconfig_off ("amd");

      # question: should we remove the symbolic links for netfs, which
      # mounts external net-based drives?
    }
}


sub DeactivateATD {

# We disable atd.  All the functionality of at can be mimicked via cron and
# there have been large security problems with cron.

   if ($GLOBAL_CONFIG{"MiscellaneousDaemons"}{"atd"} eq "Y") {
       &ActionLog("# sub DeactivateATD\n");
      &B_chkconfig_off ("atd");
   }
}



sub DeactivatePCMCIA {

    # If this isn't a notebook, strongly recommend disabling PCMCIA.
    if ($GLOBAL_CONFIG{"MiscellaneousDaemons"}{"pcmcia"} eq "Y") {
	&ActionLog("# sub DeactivatePCMCI\n");

	&B_chkconfig_off ("pcmcia");
   }
}

sub DeactivateDHCP {

    # If this is # If this is not a DHCP server, we deactivate dhcpd.

    if ($GLOBAL_CONFIG{"MiscellaneousDaemons"}{"dhcpd"} eq "Y") {
	&ActionLog("# sub DeactivateDHCP\n");

	&B_chkconfig_off ("dhcpd");
   }
}

sub DeactivateGPM {

    if ($GLOBAL_CONFIG{"MiscellaneousDaemons"}{"gpm"} eq "Y") {
	&ActionLog("# sub DeactivateGPM\n");

	&B_chkconfig_off ("gpm");
    }
}

sub DeactivateINND {

    # Deactivate innd unless they really need a new server.
	
    if ($GLOBAL_CONFIG{"MiscellaneousDaemons"}{"innd"} eq "Y" ) {
	&ActionLog("# sub DeactivateINND\n");
	
	&B_chkconfig_off ("innd");
   }
    
}


sub DeactivateRoutingDaemons {

    # Disable gated if they're not running a router...  Otherwise, disable 
    # either gated or routed.
    
    &ActionLog("# sub DeactivateRoutingDaemons\n");

    if ($GLOBAL_CONFIG{"MiscellaneousDaemons"}{"routing"} eq "Y") {
	&B_chkconfig_off ("gated");
	&B_chkconfig_off ("routed");
    }
    elsif ($GLOBAL_CONFIG{"MiscellaneousDaemons"}{"gated"} eq "Y") {
	&B_chkconfig_off ("routed");
    }
    else {
	&B_chkconfig_off ("gated");
    }      

}


sub DeactivateNIS {

    # NIS is rather insecure.

    if ($GLOBAL_CONFIG{"MiscellaneousDaemons"}{"nis"} eq "Y") {
	&ActionLog("# sub DeactivateNIS\n");

	&B_chkconfig_off ("ypbind");
	&B_chkconfig_off ("ypserv");
	&B_chkconfig_off ("yppasswdd");
    }
}

sub DeactivateSNMPD {

    # SNMP is rather insecure.  If you need proof, go read the Phrack
    # article or read a bit about the protocol...
    
    if ($MiscellaneousDaemons eq "Y") {
	&ActionLog("# sub DeactivateSNMPD\n");

	&B_chkconfig_off ("snmpd");
    }
}

###
### Should we disable the rest?
###


1;
